==> 0.0.1.tar.gz: ios/Classes/FLHyperKycHelper.swift <==
//
//  FLHyperKycHelper.swift
//  hyperkyc_flutter
//
//  Created by Shrirama Upadhya A on 26/01/22.
//

import Foundation
import HyperKYC

class FLHyperKycHelper {
    
    static func getStringFromProperty(property: String?) -> String{
        if let property = property {
            return property
        } else {
            return FLHyperKycConstants.EMPTY_STRING
        }
    }
    
    static func getResponseHeadersJsonString(responseHeaders: [String: String]) -> String {
        var responseHeadersJsonString = FLHyperKycConstants.EMPTY_JSON_STRING
        do {
            let headersData = try JSONSerialization.data(withJSONObject: responseHeaders , options: JSONSerialization.WritingOptions.prettyPrinted)
            responseHeadersJsonString = String(data: headersData, encoding: String.Encoding.utf8) ?? FLHyperKycConstants.EMPTY_JSON_STRING
            return responseHeadersJsonString
        } catch let parseError{
            print("JSON Error Parsing ResponseHeaders : \(parseError.localizedDescription)")
            return responseHeadersJsonString
        }
    }
    
    static func getResponseResultJsonString(docDataResponseResult: DocCaptureApiDetail?, faceDataResponseResult: FaceCaptureApiDetail?, faceMatchDataResponseResult: FaceMatchApiDetail?) -> String {
        let encoder = JSONEncoder()
        encoder.outputFormatting = .prettyPrinted
        var responseResultJsonString = FLHyperKycConstants.EMPTY_JSON_STRING
        do {
            if let responseResult = docDataResponseResult {
                let responseResultData = try encoder.encode(responseResult)
                responseResultJsonString = String(data: responseResultData, encoding: .utf8) ?? FLHyperKycConstants.EMPTY_JSON_STRING
                return responseResultJsonString
            } else if let responseResult = faceDataResponseResult {
                let responseResultData = try encoder.encode(responseResult)
                responseResultJsonString = String(data: responseResultData, encoding: .utf8) ?? FLHyperKycConstants.EMPTY_JSON_STRING
                return responseResultJsonString
            } else if let responseResult = faceMatchDataResponseResult {
                let responseResultData = try encoder.encode(responseResult)
                responseResultJsonString = String(data: responseResultData, encoding: .utf8) ?? FLHyperKycConstants.EMPTY_JSON_STRING
                return responseResultJsonString
            } else {
                return responseResultJsonString
            }
        } catch let parseError {
            print("JSON Error DocData ResponseResult : \(parseError.localizedDescription)")
            return responseResultJsonString
        }
    }
}

==> 0.2.0.tar.gz: ios/Classes/FLHyperKycHelper.swift <==
//
//  FLHyperKycHelper.swift
//  hyperkyc_flutter
//
//  Created by Shrirama Upadhya A on 26/01/22.
//

import Foundation
import HyperKYC

class FLHyperKycHelper {
    
    static func getStringFromProperty(property: String?) -> String{
        if let property = property {
            return property
        } else {
            return FLHyperKycConstants.EMPTY_STRING
        }
    }
    
    static func getVariablesString(variablesDictionary: [String: String]) -> String {
        var variablesString = FLHyperKycConstants.EMPTY_JSON_STRING
        do {
            let variablesData = try JSONSerialization.data(withJSONObject: variablesDictionary , options: JSONSerialization.WritingOptions.prettyPrinted)
            variablesString = String(data: variablesData, encoding: String.Encoding.utf8) ?? FLHyperKycConstants.EMPTY_JSON_STRING
            return variablesString
        } catch let parseError{
            print("JSON Error Parsing VariablesDictionary : \(parseError.localizedDescription)")
            return variablesString
        }
    }
    
    static func getResponseHeadersJsonString(responseHeaders: [String: Any]) -> String {
        var responseHeadersJsonString = FLHyperKycConstants.EMPTY_JSON_STRING
        do {
            let headersData = try JSONSerialization.data(withJSONObject: responseHeaders , options: JSONSerialization.WritingOptions.prettyPrinted)
            responseHeadersJsonString = String(data: headersData, encoding: String.Encoding.utf8) ?? FLHyperKycConstants.EMPTY_JSON_STRING
            return responseHeadersJsonString
        } catch let parseError{
            print("JSON Error Parsing ResponseHeaders : \(parseError.localizedDescription)")
            return responseHeadersJsonString
        }
    }
    
    static func getResponseResultJsonString(docDataResponseResult: DocCaptureApiDetail?, faceDataResponseResult: FaceCaptureApiDetail?, faceMatchDataResponseResult: FaceMatchApiDetail?) -> String {
        let encoder = JSONEncoder()
        encoder.outputFormatting = .prettyPrinted
        var responseResultJsonString = FLHyperKycConstants.EMPTY_JSON_STRING
        do {
            if let responseResult = docDataResponseResult {
                let responseResultData = try encoder.encode(responseResult)
                responseResultJsonString = String(data: responseResultData, encoding: .utf8) ?? FLHyperKycConstants.EMPTY_JSON_STRING
                return responseResultJsonString
            } else if let responseResult = faceDataResponseResult {
                let responseResultData = try encoder.encode(responseResult)
                responseResultJsonString = String(data: responseResultData, encoding: .utf8) ?? FLHyperKycConstants.EMPTY_JSON_STRING
                return responseResultJsonString
            } else if let responseResult = faceMatchDataResponseResult {
                let responseResultData = try encoder.encode(responseResult)
                responseResultJsonString = String(data: responseResultData, encoding: .utf8) ?? FLHyperKycConstants.EMPTY_JSON_STRING
                return responseResultJsonString
            } else {
                return responseResultJsonString
            }
        } catch let parseError {
            print("JSON Error DocData ResponseResult : \(parseError.localizedDescription)")
            return responseResultJsonString
        }
    }
}
